#ifdef LOCAL
#define _GLIBCXX_DEBUG
#endif

#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using ull = unsigned long long;

using ld = long double;

mt19937_64 mt(736736);

const int inf = int(1e9);

struct edge
{
	int to, cap;
};

struct flow
{
	int n, s, t;
	vector<edge> e;
	vector<vector<int>> g;

	flow(const int n_) : n(n_), s(n_ - 2), t(n_ - 1), e(), g(n_)
	{
	}

	void add_edge(const int from, const int to, const int cap)
	{
		g[from].push_back(int(e.size()));
		e.push_back(edge{to, cap});
		g[to].push_back(int(e.size()));
		e.push_back(edge{from, 0});
	}

	vector<int> ptr, dist;

	int add_flow()
	{
		ptr.assign(n, 0);
		dist.assign(n, -1);

		queue<int> q;
		dist[s] = 0;
		q.push(s);

		while (!q.empty())
		{
			int cur = q.front();
			q.pop();
			for (int num : g[cur])
			{
				int dest = e[num].to, cap = e[num].cap;
				if (cap > 0 && dist[dest] == -1)
				{
					dist[dest] = dist[cur] + 1;
					q.push(dest);
				}
			}
		}

		return dfs(s, inf);
	}

	int dfs (int v, int limit)
	{
		if (v == t || limit == 0)
			return limit;

		int rem = limit;
		for (; ptr[v] < int(g[v].size()); ptr[v]++)
		{
			if (rem == 0)
				return limit;

			int num = g[v][ptr[v]];
			int to = e[num].to, cap = e[num].cap;

			if (cap > 0 && dist[to] == dist[v] + 1)
			{
				int pushed = dfs(to, min(rem, cap));
				e[num].cap -= pushed;
				e[num ^ 1].cap += pushed;
				rem -= pushed;
			}
		}

		return limit - rem;
	};

	int max_flow()
	{
		int ans = 0;
		while (int add = add_flow())
			ans += add;
		return ans;
	}

	void dfs_cut(int v, vector<int> &reach)
	{
		reach.push_back(v);
		used[v] = true;

		for (int num : g[v])
			if (e[num].cap > 0 && !used[e[num].to])
				dfs_cut(e[num].to, reach);
	}

	vector<bool> used;
	vector<int> get_cut()
	{
		used.assign(n, false);
		vector<int> reach;
		dfs_cut(s, reach);
		return reach;
	}
};

void solve(istream &cin = std::cin, ostream &cout = std::cout)
{
	int n, m;
	cin >> n >> m;

	vector<int> a(m);
	for (auto &it : a)
		cin >> it;

	vector<vector<int>> c(n, vector<int>(m));
	for (auto &row : c)
		for (auto &it : row)
			cin >> it;

	vector<vector<int>> d(n, vector<int>(n));
	for (auto &row : d)
		for (auto &it : row)
			cin >> it;

	vector<int> ids(m);
	iota(ids.begin(), ids.end(), 0);
	sort(ids.begin(), ids.end(), [&](const int x, const int y)
	{ return a[x] < a[y]; });

	ll ans = 0;
	vector<int> cnt_left(n);
	vector<bool> last_used(n, false);

	vector<int> res_x(n, a[ids.back()]);
	for (int it = 0; it + 1 < int(ids.size()); it++)
	{
		flow flow(2 * n + 2);
		for (int i = 0; i < n; i++)
			for (int j = 0; j < n; j++)
			{
				flow.add_edge(i, j + n, i == j ? inf : d[i][j]);
				flow.add_edge(j + n, i, i == j ? inf : d[i][j]);
			}

		for (int i = 0; i < n; i++)
		{
			int left = 0, right = 0;
			for (int j = 0; j <= it; j++)
				right += c[i][ids[j]];
			for (int j = it + 1; j < int(ids.size()); j++)
				left += c[i][ids[j]];
			flow.add_edge(flow.s, i, 2 * right);
			flow.add_edge(i + n, flow.t, 2 * left);
		}

		const int cur = flow.max_flow();
		assert(cur % 2 == 0);
		assert(a[ids[it]] <= a[ids[it + 1]]);
		ans += (cur / 2) * ll(a[ids[it + 1]] - a[ids[it]]);

		auto cur_cut = flow.get_cut();
		{
			vector<int> only_left;
			for (const int x : cur_cut)
				if (0 <= x && x < n)
					only_left.push_back(x);
			cur_cut = only_left;
		}

		for (const int pos : cur_cut)
			cnt_left[pos]++;

		for (int i = 0; i < n; i++)
			if (last_used[i])
				assert(count(cur_cut.begin(), cur_cut.end(), i) > 0);
		last_used.assign(n, false);
		for (const int x : cur_cut)
			last_used[x] = true;
	}

	for (int i = 0; i < n; i++)
		res_x[i] = a[ids[m - 1 - cnt_left[i]]];

	ll real_ans = 0;
	for (int i = 0; i < n; i++)
	{
		for (int j = 0; j < i; j++)
			real_ans += ll(abs(res_x[i] - res_x[j])) * ll(d[i][j]);
		for (int j = 0; j < m; j++)
			real_ans += ll(abs(res_x[i] - a[j])) * ll(c[i][j]);
	}

	cerr << ans << ' ' << real_ans << endl;
	assert(ans == real_ans);
	cout << ans << endl;
	for (int i = 0; i < n; i++)
		cout << res_x[i] << " \n"[i + 1 == n];
	cout.flush();
}

void gen (ostream &cout)
{
	static mt19937 rng;
	const int n = rng() % 6 + 1;
	const int m = rng() % 6 + 1;
//	const int m = 3;
//	vector<int> a = {0, 5, 10};

	vector<int> a(m);
	for (auto &it : a)
		it = rng() % int(1e6) + 1;

	cout << n << ' ' << m << endl;
	for (int i = 0; i < m; i++)
		cout << a[i] << " ";
	cout << endl;

	for (int i = 0; i < n; i++)
	{
		for (int j = 0; j < m; j++)
			cout << rng() % 50 + 1 << ' ';
		cout << endl;
	}

	vector<vector<int>> d(n, vector<int>(n));

	for (int i = 0; i < n; i++)
		for (int j = 0; j < i; j++)
			d[i][j] = d[j][i] = rng() % 50 + 1;

	for (int i = 0; i < n; i++)
	{
		for (auto it : d[i])
			cout << it << ' ';
		cout << endl;
	}
}

int main()
{
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);

#ifdef LOCAL
	while (true)
	{
		stringstream test, out;
		gen(test);
		cerr << test.str() << endl;
		solve(test, out);
	}

	auto st = clock();

	ifstream fin("../input.txt");
	do
	{
		solve(fin);

		cout << "===" << endl;

		string str;
		while (getline(fin, str) && str != string(max(1, (int) str.size()), '='));
	} while (fin);

	cout << setprecision(6) << "clock: " << double(clock() - st) / CLOCKS_PER_SEC << endl;
#else
	solve();
#endif

	return 0;
}
