#include <bits/stdc++.h>

using namespace std;

typedef pair<int, int> pii;
typedef pair<long long, long long> pll;
typedef long long ll;
typedef unsigned int ui;
typedef unsigned long long ull;
typedef long double ld;

const int inf = 1e9;
const ll inf64 = 1e18;

const ld eps = 1e-6;
const ld X = 1e9;
const ld MAX_DIST = 1e18;

inline ld sqr(ld x) {
    return x * x;
}

struct pt {
    ld x = 0;
    ld y = 0;

    pt operator - (const pt& o) const {
        return {x - o.x, y - o.y};
    }

    pt operator + (const pt& o) const {
        return {x + o.x, y + o.y};
    }

    pt operator * (ld coef) const {
        return {x * coef, y * coef};
    }

    ld vector_mul(const pt& o) const {
        return x * o.y - o.x * y;
    }

    ld scalar_mul(const pt& o) const {
        return x * o.x + y * o.y;
    }

    ld norm() const {
        return sqrtl(max(ld(0), sqr_norm()));
    }

    void show() {
        cout << "(" << x << " " << y << ") ";
    }

    bool operator < (const pt& o) const {
        if (abs(x - o.x) < eps)
            return y < o.y;
        return x < o.x;
    }

    bool operator == (const pt& o) const {
        return (*this - o).norm() < eps;
    }

private :
    ld sqr_norm() const {
        return scalar_mul(*this);
    }
};

struct Edge {
    pt fr;
    pt to;
};

void read(int& n, ld& L, vector<ld>& d, vector<ld>& h) {
    cin >> n >> L;
    d.resize(n + 1);
    h.resize(n + 1);
    for (int i = 1; i <= n; i++) {
        cin >> d[i];
    }
    for (int i = 1; i <= n; i++) {
        cin >> h[i];
    }
}

vector<vector<pair<pt, pt>>> get_avail_jump_to_right(int n, ld L, vector<ld> d, vector<ld> h, vector<Edge>& edges) {
    ld sqr_L = sqr(L);
    vector<vector<pair<pt, pt>>> avail(n + 1, vector<pair<pt, pt>>(n + 1));
    for (int i = 0; i <= n; i++) {
        for (int j = 0; j <= n; j++) {
            auto& [l, r] = avail[i][j];
            l = {+X, 0};
            r = {-X, 0};
        }
    }
    auto get_left = [&](int i) -> pt {
        return {d[i - 1], h[i]};
    };
    auto get_right = [&](int i) -> pt {
        return {d[i], h[i]};
    };
    // jump to right
    for (int i = 1; i <= n; i++) {
        pt upper = {0, -1};
        for (int j = i + 1; j <= n; j++) {
            if (h[j] > h[i])
                break;
            pt A = get_right(i);
            pt B = get_left(j);
            if (abs(h[i] - h[j]) < eps) {
                if ((A - B).norm() <= L + eps)
                    edges.push_back({A, B});
                break;
            }
            pt v = B - A;
            if (v.vector_mul(upper) > eps)
                v = upper;
            pt C = get_right(j);
            if ((C - A).vector_mul(v) > eps) {
                upper = v;
                continue;
            }
            ld k = (B - A).y / v.y;
            pt q = A + v * k;
            if ((q - A).norm() <= L + eps) {
                ld lx = q.x;
                ld rx = C.x;
                ld T = max(ld(0), sqr_L - sqr(q.y - A.y));
                T = sqrtl(T);
                lx = max(lx, -T + A.x);
                rx = min(rx, +T + A.x);
                if (lx <= rx + eps) {
                    pt lq = q;
                    pt rq = q;
                    lq.x = lx;
                    rq.x = rx;
                    avail[i][j] = {lq, rq};
                    edges.push_back({A, lq});
                    edges.push_back({A, rq});
                    edges.push_back({lq, C});
                    edges.push_back({rq, C});
                }
            }
            upper = C - A;
        }
    }
    return avail;
}

void sort_and_delete_unique(vector<pt>& pts) {
    sort(pts.begin(), pts.end());
    int sz = (int) pts.size();
    vector<pt> hlp;
    for (int i = 0; i < sz; i++){
        int j = i;
        while (j < sz && pts[i] == pts[j])
            j++;
        hlp.push_back(pts[i]);
        i = j - 1;
    }
    pts = hlp;
}

ld find_dist(pt st, pt fn, vector<Edge> edges) {
    vector<pt> pts;
    for (auto edge : edges) {
        pts.push_back(edge.fr);
        pts.push_back(edge.to);
    }
    sort_and_delete_unique(pts);
    int sz = (int) pts.size();
    auto get_pos = [&](pt p) -> int {
        int pos = lower_bound(pts.begin(), pts.end(), p) - pts.begin();
        pos = min(pos, sz - 1);
        int mx_delta = 2;
        ld best_dist = 1e18;
        int best_pos = -1;
        for (int delta = -mx_delta; delta <= mx_delta; delta++) {
            int j = pos + delta;
            if (j < 0 || j >= sz)
                continue;
            ld dist = (pts[j] - p).norm();
            if (dist < best_dist) {
                best_dist = dist;
                best_pos = j;
            }
        }
        return best_pos;
    };
    vector<vector<pair<int, ld>>> g(sz);
//    for (int i = 0; i < sz; i++) {
//        cout << i << " : "; pts[i].show(); cout << "\n";
//    }
    for (auto edge : edges) {
        pt fr = edge.fr;
        pt to = edge.to;
        int u = get_pos(fr);
        int v = get_pos(to);
//        fr.show(); cout << " -> "; to.show(); cout << " | " << u << " -> " << v << "\n";
        g[u].emplace_back(v, (fr - to).norm());
        g[v].emplace_back(u, (fr - to).norm());
    }
    int st_pos = get_pos(st);
    int fn_pos = get_pos(fn);
    vector<ld> dist(sz, MAX_DIST);
    vector<int> from(sz, -1);
    dist[st_pos] = 0;
    set<pair<ld, int>> Q;
    Q.insert({dist[st_pos], st_pos});
    while (!Q.empty()) {
        auto [D, v] = *Q.begin();
        Q.erase(Q.begin());
        if (abs(dist[v] - D) >= eps)
            continue;
        for (auto [to, w] : g[v]) {
            if (dist[to] > dist[v] + w) {
                dist[to] = dist[v] + w;
                Q.insert({dist[to], to});
                from[to] = v;
            }
        }
    }
//    for (int x = fn_pos; ; x = from[x]) {
//        pts[x].show(); cout << " <- ";
//        if (x == st_pos)
//            break;
//    }
//    cout << "\n";
    return dist[fn_pos];
}

ld fast(int n, ld L, vector<ld> d, vector<ld> h) {
    vector<Edge> left_edges, right_edges;
    vector<vector<pair<pt, pt>>> right_avail = get_avail_jump_to_right(n, L, d, h, right_edges);
    vector<ld> rd = d, rh = h;
    reverse(rh.begin() + 1, rh.end());
    reverse(rd.begin(), rd.end());
    for (int i = 0; i <= n; i++)
        rd[i] = d[n] - rd[i];
    vector<vector<pair<pt, pt>>> left_avail = get_avail_jump_to_right(n, L, rd, rh, left_edges);
    vector<vector<pair<pt, pt>>> avail = right_avail;
    vector<Edge> edges = right_edges;
//    for (int i = 1; i <= n; i++) {
//        for (int j = i + 1; j <= n; j++) {
//            auto [p, q] = avail[i][j];
//            if (abs(p.x - X) < eps)
//                continue;
//            cout << i << " -> " << j << " [ " << p.x << " .. " << q.x << " ]\n";
//        }
//    }
//    cout << "\n";

    for (int i = 1; i <= n; i++) {
        for (int j = 1; j < i; j++) {
            int ri = n - i + 1;
            int rj = n - j + 1;
            auto [p, q] = left_avail[ri][rj];
            if (abs(p.x - X) < eps)
                continue;
            swap(p, q);
            p.x = d[n] - p.x;
            q.x = d[n] - q.x;
            avail[i][j] = {p, q};
//            cout << i << " -> " << j << "[" << p.x << " .. " << q.x << "]\n";
        }
    }
    for (auto edge : left_edges) {
        swap(edge.fr, edge.to);
        edge.fr.x = d[n] - edge.fr.x;
        edge.to.x = d[n] - edge.to.x;
        edges.push_back(edge);
    }
    auto get_left = [&](int i) -> pt {
        return {d[i - 1], h[i]};
    };
    auto get_right = [&](int i) -> pt {
        return {d[i], h[i]};
    };
    vector<vector<pt>> interesting(n + 1);
    for (int i = 1; i <= n; i++) {
        for (int j = 1; j <= n; j++) {
            if (i == j)
                continue;
            auto [p, q] = avail[i][j];
            if (abs(p.x - X) < eps)
                continue;
            interesting[j].push_back(p);
            interesting[j].push_back(q);
        }
    }
    // galochki
    for (int i = 1; i <= n; i++) {
        for (int k = i + 1; k <= n; k++) {
            for (int j = k + 1; j <= n; j++) {
                auto [pi, qi] = avail[i][k];
                auto [pj, qj] = avail[j][k];
                if (abs(pi.x - X) < eps || abs(pj.x - X) < eps)
                    continue;
                ld lx = max(pi.x, pj.x);
                ld rx = min(qi.x, qj.x);
                if (lx > rx)
                    continue;
                pt p = {lx, h[k]};
                pt q = {rx, h[k]};
                pt A = get_right(i);
                pt B = get_left(j);
                edges.push_back({A, p});
                edges.push_back({p, B});
                edges.push_back({A, q});
                edges.push_back({q, B});
                pt nB = {B.x, q.y - (B.y - q.y)};
                ld y0 = q.y;
                assert(A.y >= y0);
                assert(B.y >= y0);
                ld dy = A.y - y0;
                assert(dy >= 0);
                assert(A.y > nB.y);
                ld dx = dy * (nB.x - A.x) / (A.y - nB.y);
                assert(dx >= 0);
                ld x0 = A.x + dx;
                interesting[k].push_back(p);
                interesting[k].push_back(q);
//                cout << i << " -> " << k << " -> " << j << " [" << lx << " .. " << rx << "], (" << x0 << ", " << y0 << "), dx = " << dx << ", " << dy << "\n";
                if (lx <= x0 + eps && x0 <= rx + eps) {
                    pt p0 = {x0, y0};
                    edges.push_back({A, p0});
                    edges.push_back({p0, B});
                    interesting[k].push_back(p0);
                }
            }
        }
    }

    for (int i = 1; i <= n; i++) {
        interesting[i].push_back(get_left(i));
        interesting[i].push_back(get_right(i));
        sort(interesting[i].begin(), interesting[i].end());
        for (int j = 0; j + 1 < (int) interesting[i].size(); j++) {
            pt fr = interesting[i][j];
            pt to = interesting[i][j + 1];
            edges.push_back({fr, to});
        }
    }

    // show
//    cout << "\n";
//    for (auto edge : edges) {
//        edge.fr.show(); cout << " -> "; edge.to.show(); cout << "\n";
//    }
    return find_dist(get_left(1), get_right(n), edges);
}

void work() {
    int n;
    ld L;
    vector<ld> d, h;
    read(n, L, d, h);
    ld fs = fast(n, L, d, h);
    if (abs(fs - MAX_DIST) < eps) {
        cout << "-1\n";
    } else {
        cout << fs << "\n";
    }
}

int main() {

#ifdef DEBUG
    freopen("input.txt", "r", stdin);
#endif

    ios_base::sync_with_stdio(0);
    cin.tie(0);

    cout.precision(20);
    cout << fixed;

    work();

    return 0;
}
