#include <iostream>
#include <cstdio>
#include <vector>
#include <algorithm>
#include <queue>
#include <deque>
#include <stack>
#include <map>
#include <set>
#include <unordered_map>
#include <unordered_set>
#include <cassert>
#include <cstddef>
#include <cstring>
#include <bitset>
#include <random>
#include <memory>
#include <iomanip>

typedef long long ll;
typedef long double ld;

using namespace std;

const int inf = 1e9 + 7;

int test;

struct Dinic {

    struct Edge {
        int fr, to, cp, id, fl;
    };

    int n, S, T;
    vector< Edge > es;
    vector< vector< int > > g;
    vector< int > dist, res, ptr;

    Dinic(int n_, int S_, int T_):
            n(n_), S(S_), T(T_)
    {
        g.resize(n);
    }


    vector<int> used;

    void dfs_simple(int v) {
        used[v] = 1;
        for (int i : g[v]) {
            Edge &e = es[i];
            if (e.fl != e.cp && !used[e.to]) {
                dfs_simple(e.to);
            }
        }
    }

    vector<int> get_left() {
        used.assign(n, 0);
        dfs_simple(S);
        vector<int> ans;
        for (int i = 0; i < n; i++) if (used[i] && i != S) ans.push_back(i);
        return ans;
    }


    void add_edge(int fr, int to, int cp, int id) {
        g[fr].push_back((int)es.size());
        es.push_back({fr, to, cp, id, 0});
        g[to].push_back((int)es.size());
        es.push_back({to, fr, 0, -1, 0});
    }

    bool bfs(int K) {
        dist.assign(n, inf);
        dist[S] = 0;
        queue< int > q;
        q.push(S);
        while(!q.empty()) {
            int v = q.front();
            q.pop();
            for(int ps : g[v]) {
                Edge &e = es[ps];
                if(e.fl + K > e.cp) continue;
                if(dist[e.to] > dist[e.fr] + 1) {
                    dist[e.to] = dist[e.fr] + 1;
                    q.push(e.to);
                }
            }
        }
        return dist[T] < inf;
    }

    int dfs(int v, int _push = inf) {
        if(v == T || !_push) return _push;
        for(int &iter = ptr[v];iter < (int)g[v].size();iter++) {
            int ps = g[v][ ptr[v] ];
            Edge &e = es[ps];
            if(dist[e.to] != dist[e.fr] + 1) continue;
            int tmp = dfs(e.to, min(_push, e.cp - e.fl));
            if(tmp) {
                e.fl += tmp;
                es[ps ^ 1].fl -= tmp;
                return tmp;
            }
        }
        return 0;
    }

    ll find_max_flow() {
        ptr.resize(n);
        ll max_flow = 0, add_flow;
        for(int K = 1 << 30;K > 0;K >>= 1) {
            while(bfs(K)) {
                ptr.assign(n, 0);
                while((add_flow = dfs(S))) {
                    max_flow += add_flow;
                }
            }
        }
        return max_flow;
    }

    void assign_result() {
        res.resize(es.size());
        for(Edge e : es) if(e.id != -1) res[e.id] = e.fl;
    }

    int get_flow(int id) {
        return res[id];
    }

    bool go(int v, vector< int > &F, vector< int > &path) {
        if(v == T) return 1;
        for(int ps : g[v]) {
            if(F[ps] <= 0) continue;
            if(go(es[ps].to, F, path)) {
                path.push_back(ps);
                return 1;
            }
        }
        return 0;
    }

    vector< pair< int, vector< int > > > decomposition() {
        find_max_flow();
        vector< int > F((int)es.size()), path, add;
        vector< pair< int, vector< int > > > dcmp;
        for(int i = 0;i < (int)es.size();i++) F[i] = es[i].fl;
        while(go(S, F, path)) {
            int mn = inf;
            for(int ps : path) mn = min(mn, F[ps]);
            for(int ps : path) F[ps] -= mn;
            for(int ps : path) add.push_back(es[ps].id);
            reverse(add.begin(), add.end());
            dcmp.push_back({mn, add});
            add.clear();
            path.clear();
        }
        return dcmp;
    }
};




const int MX = 70;
int d[MX][MX];
int c[MX][MX];
vector<int> a;
int n, m;


pair<ll, vector<int>> solve(const set<int>& now, const set<int>& ws, int i) {
    Dinic din = Dinic(n + 2, n, n + 1);
    for (int k : now) {
        for (int j : now) {
            if (k != j) din.add_edge(k, j, d[k][j] * (a[i + 1] - a[i]), -1);
        }
    }
    for (int x : now) {
        for (int j = 0; j <= i; j++) {
            din.add_edge(n, x, c[x][j] * (a[i + 1] - a[i]), -1);
        }
        for (int j : ws) {
            din.add_edge(n, x, d[x][j] * (a[i + 1] - a[i]), -1);
        }
    }
    for (int x : now) {
        for (int j = i + 1; j < m; j++) {
            din.add_edge(x, n + 1, c[x][j] * (a[i + 1] - a[i]), -1);
        }
    }

    ll flow = din.find_max_flow();
    vector<int> l = din.get_left();

    return {flow, l};
}

ll stupid_ans = 1e18;
int col[MX];

void stupid(int lvl = 0) {
    if (lvl == n) {
        ll gt = 0;
        for (int i = 0; i < n; i++) {
            for (int j = 0; j < m; j++) {
                gt += abs(a[j] - a[col[i]]) * c[i][j];
            }
            for (int j = i + 1; j < n; j++) {
                gt += abs(a[col[i]] - a[col[j]]) * d[i][j];
            }
        }
        stupid_ans = min(gt, stupid_ans);

        return;
    }
    for (int i = 0; i < m; i++) {
        col[lvl] = i;
        stupid(lvl + 1);
    }
}

void read() {
    cin >> n >> m;
    a.resize(m);
    for (int i = 0; i < m; i++) {
        cin >> a[i];
    }

    vector<pair<int, int>> b(m);
    for (int i = 0; i < m; i++) b[i] = {a[i], i};
    sort(b.begin(), b.end());
    sort(begin(a), end(a));
    vector<int> back(m);
    for (int i = 0; i < m; i++) back[b[i].second] = i;

    for (int i = 0; i < n; i++)
        for (int j = 0; j < m; j++) {
            cin >> c[i][back[j]];
            // c[i][back[j]] = 50;
        }
    for (int i = 0; i < n; i++)
        for (int j = 0; j < n; j++) {
            cin >> d[i][j];
            // d[i][j] = 50;
        }
}

mt19937 gen;

void generate() {
    n = 5, m = 5;
    a.resize(m);
    for (int i = 0; i < m; i++) {
        // cin >> a[i];
        a[i] = gen() % 10;
    }

    vector<pair<int, int>> b(m);
    for (int i = 0; i < m; i++) b[i] = {a[i], i};
    sort(b.begin(), b.end());
    sort(begin(a), end(a));
    vector<int> back(m);
    for (int i = 0; i < m; i++) back[b[i].second] = i;

    for (int i = 0; i < n; i++)
        for (int j = 0; j < m; j++) {
            // cin >> c[i][back[j]];
            c[i][back[j]] = gen() % 51;
        }
    for (int i = 0; i < n; i++)
        for (int j = 0; j < n; j++) {
            // cin >> d[i][j];
            if (i > j) d[i][j] = d[j][i];
            else if (i == j) d[i][j] = 0;
            else d[i][j] = gen() % 51;
        }

}



int main() {

#ifdef LOCAL
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);
#endif
    ios_base::sync_with_stdio(0);

    read();
    // for (test = 0; test < 100; test++) {
    // generate();

    vector<vector<int>> ans(m);
    set<int> now;
    set<int> ws;
    for (int i = 0; i < n; i++) now.insert(i);

    ll sum = 0;
    for (int i = 0; i + 1 < m; i++) {
        auto [flow, prev] = solve(now, ws, i);
        for (int j : prev) {
            ans[i].push_back(j);
            now.erase(j);
            ws.insert(j);
        }
        sum += flow;
    }
    ans[m - 1] = vector<int>(now.begin(), now.end());

    vector<int> pos(n, -1);
    for (int i = 0; i < m; i++) {
        for (int j : ans[i]) {
            pos[j] = a[i];
        }
    }
    stupid_ans = 1e18;
    // stupid();

    sum = 0;
    ll gt = 0;
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            gt += abs(a[j] - pos[i]) * c[i][j];
        }
        for (int j = i + 1; j < n; j++) {
            gt += abs(pos[i] - pos[j]) * d[i][j];
        }
    }
    sum = gt;
    cout << sum << '\n';

    // cout << sum << ' ' << stupid_ans << '\n';
    // if (sum != stupid_ans) {
        // cout << test << '\n';
        // cout << sum << ' ' << stupid_ans << '\n';
        // for (int i : a) cout << i << ' ';
        // cout << '\n';
        // for (int i = 0; i < n; i++) {
            // for (int j = 0; j < m; j++) {
                // // cin >> c[i][back[j]];
                // cout << c[i][j] << ' ';
            // }
            // cout << '\n';
        // }
        // for (int i = 0; i < n; i++) {
            // for (int j = 0; j < n; j++) {
                // // cin >> d[i][j];
                // // d[i][j] = gen() % 51;
                // cout << d[i][j] << ' ';
            // }
            // cout << '\n';
        // }
        // break;

    // }
    for (int i : pos) cout << i << ' ';
    cout << '\n';


    return 0;
}
