//  Copyright 2020 Nikita Golikov

#include <bits/stdc++.h>

using namespace std;

using i64 = int64_t;
using ui64 = uint64_t;

template <class A, class B>
bool smin(A &x, B &&y) {
  if (y < x) {
    x = y;
    return true;
  }
  return false;
}

template <class A, class B>
bool smax(A &x, B &&y) {
  if (x < y) {
    x = y;
    return true;
  }
  return false;
}

#include <ext/pb_ds/assoc_container.hpp>

using namespace __gnu_pbds;

struct chash {
  static auto const C = (ui64) 7e18 + 23;
  static_assert(C % 2);

  ui64 const RANDOM = chrono::steady_clock::now().time_since_epoch().count();
  ui64 operator()(ui64 x) const {
    return __builtin_bswap64((x ^ RANDOM) * C);
  }
  auto operator()(tuple<int, int, int> x) const {
    return (i64) get<0>(x) * 31 * 33 + (i64) get<1>(x) * 37 + get<2>(x);
  }
};

template <class T> using hash_set = gp_hash_table<T, null_type, chash>;
template <class K, class V> using hash_map = gp_hash_table<K, V, chash>;

int main() {
#ifdef GOLIKOV
  assert(freopen("in", "rt", stdin));
  auto _clock_start = chrono::high_resolution_clock::now();
#endif
  ios::sync_with_stdio(false);
  cin.tie(nullptr);

  string s, t;
  cin >> s >> t;

  int const MOD1 = (int) 1e9 + 7;
  int const MOD2 = (int) 1e9 + 9;
  int const MOD3 = (int) 1e9 + 21;
  int const B1 = 291;
  int const B2 = 273;
  int const B3 = 413;
  auto get_hash = [](string const& s) {
    int x = 0;
    int y = 0;
    int z = 0;
    for (char ch : s) {
      x = ((i64) x * B1) % MOD1;
      x = (x + ch) % MOD1;
      y = ((i64) y * B2) % MOD2;
      y = (y + ch) % MOD2;
      z = ((i64) z * B3) % MOD3;
      z = (z + ch) % MOD3;
    }
    return make_tuple(x, y, z);
  };

  vector<char> letters;
  for (char ch : s) letters.push_back(ch);
  for (char ch : t) letters.push_back(ch);
  sort(letters.begin(), letters.end());
  letters.erase(unique(letters.begin(), letters.end()), letters.end());
  auto nlet = (int) letters.size();
  auto char_to_id = [&](char ch) {
    auto it = (int) (lower_bound(letters.begin(), letters.end(), ch)
      - letters.begin());
    if (it == nlet || letters[it] != ch) return -1;
    return it;
  };
  if (nlet > 10) {
    cout << 0 << '\n';
    return 0;
  }
  vector<int> let_to_dig(nlet, -1);
  vector<int> dig_to_let(10, -1);
  auto convert = [&](string const& s) {
    int ans = 0;
    for (char ch : s) {
      ans *= 10;
      ans += let_to_dig[char_to_id(ch)];
    }
    return ans;
  };
  vector<bool> used(10);
  hash_map<tuple<int, int, int>, int> patterns;
  auto gen = [&](auto&& gen, int i) -> void {
    if (i == nlet) {
      auto x = convert(s);
      auto y = convert(t);
      if (let_to_dig[char_to_id(s[0])] == 0) {
        return;
      }
      if (let_to_dig[char_to_id(t[0])] == 0) {
        return;
      }
      auto z = x + y;
      auto str_z = to_string(z);
      map<char, int> was;
      for (char& ch : str_z) {
        auto id = ch - '0';
        if (dig_to_let[id] >= 0) {
          ch = letters[dig_to_let[id]];
        } else {
          if (!was.count(ch)) {
            was[ch] = (int) was.size();
          }
          ch = (char) ('a' + was[ch]);
        }
      }
      patterns[get_hash(str_z)]++;
      return;
    }
    for (int d = 0; d < 10; ++d) {
      if (dig_to_let[d] < 0) {
        dig_to_let[d] = i;
        let_to_dig[i] = d;
        gen(gen, i + 1);
        dig_to_let[d] = -1;
        let_to_dig[i] = -1;
      }
    }
  };
  gen(gen, 0);
  cerr << patterns.size() << '\n';
  int n;
  cin >> n;
  vector<string> ans;
  while (n--) {
    string pat;
    cin >> pat;
    auto init = pat;
    map<char, int> mp;
    for (char& ch : pat) {
      auto id = char_to_id(ch);
      if (id == -1) {
        if (!mp.count(ch)) mp[ch] = (int) mp.size();
        ch = (char) ('a' + mp[ch]);
      }
    }
    if (patterns[get_hash(pat)] == 1) {
      ans.push_back(init);
    }
  }
  cout << ans.size() << '\n';
  for (auto const& pat : ans) {
    cout << pat << '\n';
  }

#ifdef GOLIKOV
  cerr << "Executed in " << chrono::duration_cast<chrono::milliseconds>(
      chrono::high_resolution_clock::now()
          - _clock_start).count() << "ms." << endl;
#endif
  return 0;
}
