#include <iostream>
#include <algorithm>
#include <cmath>

using lint = long long;
lint gcd (lint a, lint b, lint & x, lint & y) {
    if (a == 0) {
        x = 0; y = 1;
        return b;
    }
    lint x1, y1;
    lint d = gcd (b%a, a, x1, y1);
    x = y1 - (b / a) * x1;
    y = x1;
    return d;
}

bool find_any_solution (lint a, lint b, lint c, lint & x0, lint & y0, lint & g) {
    g = gcd (std::abs(a), std::abs(b), x0, y0);
    if (c % g != 0)
        return false;
    x0 *= c / g;
    y0 *= c / g;
    if (a < 0)   x0 *= -1;
    if (b < 0)   y0 *= -1;
    return true;
}

void shift_solution (lint & x, lint & y, lint a, lint b, lint cnt) {
    x += cnt * b;
    y -= cnt * a;
}

lint cnt_pos_solutions(lint a, lint b, lint c) {

    lint x, y, g;
    if (!find_any_solution(a, b, c, x, y, g)) {
        return 0;
    }

    a /= g;
    b /= g;

    int sign_a = a>0 ? +1 : -1;
    int sign_b = b>0 ? +1 : -1;

    shift_solution (x, y, a, b, (1 - x) / b);
    if (x < 1)
        shift_solution (x, y, a, b, sign_b);

    shift_solution (x, y, a, b, - (1 - y) / a);
    if (y < 1)
        shift_solution (x, y, a, b, -sign_a);

    if (x < 1 || y < 1) {
        return 0;
    }

    lint cnt_l = -x / b - 1;
    lint cnt_r = y / a + 1;

    while ((x + cnt_l * b) < 1) {
        ++cnt_l;
    }
    while ((y - cnt_r * a) < 1) {
        --cnt_r;
    }

    if (cnt_l > cnt_r) {
        std::swap(cnt_l, cnt_r);
    }

    return (cnt_r - cnt_l + 1);
}

lint solve(lint b, lint d) {

    return cnt_pos_solutions(d, b, b * b);
}

int main() {

    int tc;
    std::cin >> tc;

    while (tc--) {
        lint b, d;
        std::cin >> b >> d;
        lint res = solve(b, d);
        std::cout << res << '\n';
    }


    return 0;
}

/*
#include <cstring>
#include <iostream>
#include <vector>
#include <algorithm>


int par[20];
int n;
std::vector<int> g[1 << 20];

int is_beautiful(int mask) {
    // root is red
    if (!(mask & 1)) return false;

    for (int i = 1; i < n; ++i) {
        // if i is red then par[i] must be too
        if ((mask & (1 << i)) && !(mask & (1 << par[i]))) {
            return false;
        }
    }

    return true;
}

//int p[1 << 20];
//void dfs(int v) {
//    for (int i = 0; i < g[v].size(); ++i) {
//        int to = g[v][i];
//        if (!used[to]) {
//            p[to] = v;
//            used[to] = used[v] + 1;
//            dfs(to);
//        }
//    }
//}

int used_order[1 << 20];
std::vector<int> order;
void dfs_order(int v) {
    used_order[v] = 1;
    for (int i = 0; i < g[v].size(); ++i) {
        int to = g[v][i];
        if (!used_order[to]) {
            used_order[to] = 1;
            dfs_order(to);
        }
    }
    order.push_back(v);
}

int main() {
    std::cin >> n;

    for (int i = 1; i < n; ++i) {
        std::cin >> par[i];
        --par[i];
    }

    for (int mask = 1; mask < (1 << n); ++mask) {
        if (!is_beautiful(mask)) continue;
        for (int i = 0; i < n; ++i) {
            int newmask = (mask | (1 << i));
            if (newmask != mask && is_beautiful(newmask)) {
                g[mask].push_back(newmask);
                g[newmask].push_back(mask);
            }
        }
    }

    dfs_order(1);
    std::reverse(order.begin(), order.end());

    for (int i = 0; i < order.size(); ++i) {
        std::cout << order[i] << std::endl;
    }

    for (int i = 1; i < (1 << n); ++i) {
        if (is_beautiful(i)) {
            std::cout << i << " is beautiful" << std::endl;
        }
    }


    return 0;
}
*/