﻿#define _CRT_SECURE_NO_WARNINGS
#define _USE_MATH_DEFINES
#include <iostream>
#include <iomanip>
#include <cmath>
#include <map>
#include <vector>
#include <sstream>
#include <numeric>
#include <cassert>

#ifdef _DEBUG
constexpr bool debug_mode = true;
#else
constexpr bool debug_mode = false;
#endif

using namespace std;
const double EPS = 1e-9;

std::vector<std::string> split(const std::string& s, char delim) {
	std::stringstream ss(s);
	std::string part;
	std::vector<std::string> result;
	
	while (std::getline(ss, part, delim)) {
		result.push_back(part);
	}

	return result;
}

int digitToInt(char c) {
	return c - '0';
}

static vector<int> pows;
vector<int> tree;
vector<int> sums;
vector<int> indices;


inline int leftChild(int index) {
	return index * 2 + 1;
}

inline int rightChild(int index) {
	return index * 2 + 2;
}

struct Triple {
	int weight, left, right;
};

vector<Triple> ans;

void testAssert(bool cond)
{
	if (!cond) {
		exit(-1);
	}
}

void buildTree(int level, int index, int a, int b) {
	testAssert(a > 0 || b > 0);
	
	if (b != 0) {
		tree[index] = 2;
		b--;
	}
	else {
		tree[index] = 1;
		a--;
	}

	int b_left = b / 2;
	int b_right = b / 2;

	int a_left = 0;
	int a_right = 0;

	if (b % 2 != 0) {
		b_left++;

		if (a > 0) {
			if (a % 2 == 0) {
				a_right = 2;
				a -= 2;
			}
			else {
				a_right = 1;
				a--;
			}
		}

		testAssert(a % 2 == 0);
	}

	a_left += a / 2;
	a_right += a / 2;

	if (a % 2 != 0) {
		a_left++;
	}

	int sum_left = 2 * b_left + a_left;
	int sum_right = 2 * b_right + a_right;

	if (abs(sum_right - sum_left) > 1) {
		cout << -1;
		exit(0);
	}

	if (sum_left > 0) {
		buildTree(level + 1, leftChild(index), a_left, b_left);
		sums[leftChild(index)] = sum_left;
	}

	if (sum_right > 0) {
		buildTree(level + 1, rightChild(index), a_right, b_right);
		sums[rightChild(index)] = sum_right;
	}
}


static int orderIndex = 1;

void reinex(int index) {
	if (index >= tree.size() || tree[index] == 0) {
		return;
	}

	indices[index] = orderIndex++;

	reinex(leftChild(index));
	reinex(rightChild(index));
}

//#define DEBUG_PRINT 1


void printTree(int index) {
	if (index >= tree.size() || tree[index] == 0) {
		return;
	}

	int lc = leftChild(index);
	lc = (lc < tree.size() && tree[lc] != 0) ? indices[lc] : 0;

	int rc = rightChild(index);
	rc = (rc < tree.size() && tree[rc] != 0) ? indices[rc] : 0;

#if defined DEBUG_PRINT 
	if (lc != 0) {
		cout << indices[index] << " -> " << lc << endl;
	}

	if (rc != 0) {
		cout << indices[index] << " -> " << rc << endl;
	}

	cout << indices[index] << "[label=\"" << tree[index] << " - " << sums[index] << "\"]" << endl;

#else
	cout << tree[index] << " " << lc << " " << rc << endl;
#endif

	printTree(leftChild(index));
	printTree(rightChild(index));
}


int sumSubtree(int index) {
	if (index >= tree.size() || tree[index] == 0) {
		return 0;
	}

	int sum = tree[index];

	sum += sumSubtree(leftChild(index));
	sum += sumSubtree(rightChild(index));

	return sum;
}

int main() {
	using ll = long long;

#if defined _DEBUG 
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
#endif

	cout << fixed << setprecision(1);

	long long pw = 1;
	pows.push_back(pw);

	while (pw < 700000) {
		pw *= 2;
		pows.push_back(pw);
	}

	int a, b;
	cin >> a >> b;

	int levels = ceil(log2(a + b));
	tree.resize(pows[levels + 1], 0);
	sums.resize(pows[levels + 1], 0);
	indices.resize(pows[levels + 1], 0);

	buildTree(0, 0, a, b);

	int nonZero = 0;

	for (int i = 0; i < tree.size(); i++) {
		if (tree[i] != 0) {
			nonZero++;
		}
	}

	testAssert(nonZero == a + b);
	testAssert(sumSubtree(0) == a + 2 * b);

	reinex(0);
	printTree(0);

	return 0;
}
