#include <algorithm>
#include <cassert>
#include <cmath>
#include <cstring>
#include <ctime>
#include <iostream>
#include <map>
#include <numeric>
#include <queue>
#include <set>
#include <stack>
#include <string>
#include <unordered_map>
#include <unordered_set>
#include <utility>
#include <vector>
#include <queue>
#include <sstream>

#define CHECK_IMPL1(cond)                \
    if (!(cond)) {                       \
      DEBUG("expected cond: " << #cond); \
      assert(cond);                      \
    }

#define CHECK_IMPL2(cond, message)                                              \
    if (!(cond)) {                                                              \
      DEBUG("expected cond: " << #cond << " failed with message: " << message); \
      assert(cond);                                                             \
    }

#define CHECK_IMPL(_1, _2, NAME, ...) NAME
#define CHECK(...) CHECK_IMPL(__VA_ARGS__, CHECK_IMPL2, CHECK_IMPL1, CHECK_IMPL0)(__VA_ARGS__)

#ifdef __APPLE__
#define DEBUG(message) std::cerr << message << std::endl;
#else
#define DEBUG(message)
#endif

int common(const std::string& lhs, const std::string& rhs) {
  int res = 0;
  for (size_t i = 0; i < lhs.size(); ++i) {
    res += lhs[i] == rhs[i];
  }
  return res;
}

void dfs(
    const std::vector<std::vector<int>>& g,
    const std::vector<std::vector<int>>& rg,
    std::vector<bool>& win,
    std::set<std::pair<int, bool>>& was,
    int v
) {
  std::vector<int> changed;
  for (auto prev : rg[v]) {
    bool original = win[prev];
    bool can_win = false;
    for (auto to : g[prev]) {
      if (!win[to]) {
        can_win = true;
        break;
      }
    }
    if (original != can_win) {
      win[prev] = can_win;
      changed.push_back(prev);
    }
  }
  for (auto prev : changed) {
    if (was.emplace(std::pair(prev, win[prev])).second) {
      dfs(g, rg, win, was, prev);
    }
  }
}

void solve() {
  int n;
  std::cin >> n;
  std::vector<std::string> f(n);
  for (int i = 0; i < n; ++i) {
    std::cin >> f[i];
  }

  std::vector<std::vector<int>> rg(n);
  for (int i = 0; i < n; ++i) {
    for (int j = std::max(0, i - 100); j < i; ++j) {
      if (i - j <= common(f[i], f[j])) {
        rg[i].push_back(j);
      }
    }
  }

  std::vector<std::vector<int>> g(n);
  std::vector<bool> win(n);
  int cnt_0 = 0;
  std::vector<int> q;
  for (int i = 0; i < n; ++i) {
    for (int j = std::max(0, i - 100); j < i; ++j) {
      if (i - j <= common(f[i], f[j])) {
        g[j].push_back(i);
      }
    }
    win[i] = false;
    q.clear();
    q.push_back(i);
    for (size_t bfs_it = 0; bfs_it < q.size(); ++bfs_it) {
      auto v = q[bfs_it];
      for (auto prev : rg[v]) {
        bool original = win[prev];
        bool can_win = false;
        for (auto to : g[prev]) {
          if (!win[to]) {
            can_win = true;
            break;
          }
        }
        if (original != can_win) {
          win[prev] = can_win;
          q.push_back(prev);
        }
      }
    }
    cnt_0 += win[0];
    std::cout << (win[0] ? '1' : '2');
  }
  std::cout << '\n';
}

int main() {
#ifdef __APPLE__
  freopen("input.txt", "r", stdin);
  //freopen("output.txt", "w", stdout);
#endif
  std::ios_base::sync_with_stdio(false);
  std::cin.tie(0);
  int t = 1;
  //std::cin >> t;
  while (t--) {
    solve();
  }
  return 0;
}
