#include <iostream>
#include <vector>
#include <set>
#include <algorithm>
#include <cmath>
#include <queue>

using namespace std;

typedef long long ll;

#define X first
#define Y second
#define all(v) (v).begin(), (v).end()
#define inb push_back

double EPS = 1e-9;

struct Point {
    ll x, y;
    Point() {};
    Point(ll x, ll y) : x(x), y(y) {};
    Point operator-(Point a) {
        return Point(x - a.x, y - a.y);
    }
    ll operator*(Point a) { // cross product
        return x * a.y - y * a.x;
    }
    ll operator%(Point a) { // dot product
        return x * a.x + y * a.y;
    }
};

Point makeV(Point a, Point b) {
    return b - a;
}

vector<Point> t(3);

int check_horizontal(Point a, Point b, int k, int &l, int &r) {
    // Line y == k
    if (a.y == k && b.y == k) {
        if (a.x & 1) {
            ++a.x;
        }
        if (b.x & 1) {
            --b.x;
        }
        l = max(0ll, a.x / 2), r = max(0ll, b.x / 2);
        return 1;
    } else {
        return 0;
    }
}

int check_left(int x, int y) {
    Point cur = Point(x, y);
    Point v = makeV(t[0], cur);
    Point v1 = makeV(t[0], t[1]);
    ll crpr1 = v * v1;
    return crpr1 < 0;
}

int dbg = 0;

int check_right(int x, int y) {
    Point cur = Point(x, y);
    Point v = makeV(t[0], cur);
    Point v1 = makeV(t[0], t[2]);
    // if (dbg) {
    //     puts("QUERY");
    //     printf("%d %d\n", x, y);
    //     printf("%lld %lld || %lld %lld\n", v.x, v.y, v1.x, v1.y);
    //     printf("%lld\n", v * v1);
    // }
    ll crpr1 = v * v1;
    return (crpr1 < 0 || (crpr1 == 0 && v % v1 >= 0));
}

int check_right2(int x, int y) {
    Point cur = Point(x, y);
    Point v = makeV(t[2], cur);
    Point v1 = makeV(t[2], t[1]);
    // if (dbg) {
    //     puts("QUERY");
    //     printf("%d %d\n", x, y);
    //     printf("%lld %lld || %lld %lld\n", v.x, v.y, v1.x, v1.y);
    //     printf("%lld\n", v * v1);
    // }
    ll crpr1 = v * v1;
    return (crpr1 < 0 || (crpr1 == 0 && v % v1 >= 0));
}

const int MOD = 1e9 + 7;

void add(int &x, int val) {
    x += val;
    if (x >= MOD) {
        x -= MOD;
    } else if (x < 0) {
        x += MOD;
    }
}

int mul(int a, int b) {
    return (1ll * a * b) % MOD;
}

int binpow(int a, int n) {
    if (n == 0) {
        return 1;
    }
    int res = binpow(a, n >> 1);
    res = mul(res, res);
    if (n & 1) {
        res = mul(res, a);
    }
    return res;
}

int fact[1000002], rfact[1000002];

void calc_fact() {
    fact[0] = 1;
    for (int i = 1; i < 1000002; ++i) {
        fact[i] = mul(fact[i - 1], i);
    }
    rfact[0] = 1;
    rfact[1000001] = binpow(fact[1000001], MOD - 2);
    for (int i = 1000000; i > 0; --i) {
        rfact[i] = mul(rfact[i + 1], i + 1);
    }
}

int get_c(int n, int k) {
    if (k < 0) {
        return 0;
    }
    if (n < 0) {
        return 0;
    }
    return mul(mul(fact[n], rfact[k]), rfact[n - k]);
}

int calc_row(int k, int l, int r) {
    if (r == -1 || l > r) {
        return 0;
    }
    int res = get_c(k + r + 1, r);
    add(res, -get_c(k + l, l - 1));
    return res;
}

int solve() {
    t.resize(0);
    t.resize(3);
    for (int i = 0; i < 3; ++i) {
        ll x, y;
        cin >> x >> y;
        t[i] = Point(x + y, y - x);
        if (t[i].y < t[0].y || t[0].y == t[i].y && t[0].x > t[i].x) {
            swap(t[0], t[i]);
        }
    }
    // Прекальк факториалов ебучих
    calc_fact();
    // хотим, чтобы из нулевой точки вектора 
    // были по часовой стрелке
    {
        Point v1 = makeV(t[0], t[1]);
        Point v2 = makeV(t[0], t[2]);
        if (v1 * v2 > 0) {
            swap(t[1], t[2]);
        }
    }
    // puts("NEW PTS :: ");
    // for (int i = 0; i < 3; ++i) {
    //     printf("%lld %lld\n", t[i].x, t[i].y);
    // }
    int miny = t[0].y, maxy = t[0].y;
    for (int i = 0; i < 3; ++i) {
        miny = min(miny, (int)t[i].y);
        maxy = max(maxy, (int)t[i].y);
    }
    int ans = 0;
    // printf("%d %d\n", miny, maxy);
    // every line: (0, 2k) -- (2000002, 2k)
    for (int k = 0; k < 1000002; ++k) {
        if (k * 2 < miny) {
            continue;
        }
        if (k * 2 > maxy) {
            break;
        }
        // check horizontal roflan
        int ok = 0;
        int resl = 0, resr = 0;
        // ok |= check_horizontal(t[0], t[1], k * 2, resl, resr);
        // ok |= check_horizontal(t[0], t[2], k * 2, resl, resr);
        // ok |= check_horizontal(t[1], t[2], k * 2, resl, resr);
        // if (ok) {
        //     add(ans, calc_row(k, resl, resr));
        //     continue;
        // }
        // printf("K :: %d\n", k);
        // dbg = (k == 1);
        // binary search left border
        {
            int l = -1, r = 1000002;
            while (r - l > 1) {
                int mid = l + r >> 1;
                if (check_left(mid * 2, k * 2)) {
                    l = mid;
                } else {
                    r = mid;
                }
            }
            resl = r;
        }
        // binary search right border
        {
            int l = -1, r = 1000002;
            while (r - l > 1) {
                int mid = l + r >> 1;
                if (check_right(mid * 2, k * 2)) {
                    l = mid;
                } else {
                    r = mid;
                }
            }
            resr = l;
        }
        {
            int l = -1, r = resr + 1;
            while (r - l > 1) {
                int mid = l + r >> 1;
                if (check_right2(mid * 2, k * 2)) {
                    l = mid;
                } else {
                    r = mid;
                }
            }
            resr = l;
        }
        // printf("L :: %d R :: %d\n", resl, resr);
        // printf("CURRENT RESULT :: %d\n", calc_row(k, resl, resr));
        add(ans, calc_row(k, resl, resr));
    }
    printf("%d\n", ans);
	return 0;
}

int main() {
	ios_base::sync_with_stdio(0);
	cin.tie();
    int t;
    cin >> t;
    while (t--)
	solve();
	return 0;
}